pub trait Binary {
// Required method
fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>;
}Expand description
b formatting.
The Binary trait should format its output as a number in binary.
For primitive signed integers (i8 to i128, and isize),
negative values are formatted as the two’s complement representation.
The alternate flag, #, adds a 0b in front of the output.
For more information on formatters, see the module-level documentation.
Examples
Basic usage with i32:
let x = 42; // 42 is '101010' in binary
assert_eq!(format!("{x:b}"), "101010");
assert_eq!(format!("{x:#b}"), "0b101010");
assert_eq!(format!("{:b}", -16), "11111111111111111111111111110000");Implementing Binary on a type:
use std::fmt;
struct Length(i32);
impl fmt::Binary for Length {
fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
let val = self.0;
fmt::Binary::fmt(&val, f) // delegate to i32's implementation
}
}
let l = Length(107);
assert_eq!(format!("l as binary is: {l:b}"), "l as binary is: 1101011");
assert_eq!(
// Note that the `0b` prefix added by `#` is included in the total width, so we
// need to add two to correctly display all 32 bits.
format!("l as binary is: {l:#034b}"),
"l as binary is: 0b00000000000000000000000001101011"
);Required Methods
1.0.0 · Sourcefn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>
fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>
Formats the value using the given formatter.
Errors
This function should return Err if, and only if, the provided Formatter returns Err.
String formatting is considered an infallible operation; this function only
returns a Result because writing to the underlying stream might fail and it must
provide a way to propagate the fact that an error has occurred back up the stack.
Implementors
impl Binary for i8
impl Binary for i16
impl Binary for i32
impl Binary for i64
impl Binary for i128
impl Binary for isize
impl Binary for u8
impl Binary for u16
impl Binary for u32
impl Binary for u64
impl Binary for u128
impl Binary for usize
impl Binary for bf16
Available on non-
target_arch=spirv only.impl Binary for Flags
impl Binary for Functionality
impl Binary for I2CMessageFlags
impl Binary for AtFlags
impl Binary for FallocateFlags
impl Binary for nix::fcntl::FdFlag
impl Binary for OFlag
impl Binary for RenameFlags
impl Binary for SealFlag
impl Binary for SpliceFFlags
impl Binary for DeleteModuleFlags
impl Binary for ModuleInitFlags
impl Binary for MntFlags
impl Binary for nix::mount::linux::MsFlags
impl Binary for nix::mqueue::FdFlag
impl Binary for MQ_OFlag
impl Binary for InterfaceFlags
impl Binary for PollFlags
impl Binary for CloneFlags
impl Binary for EpollCreateFlags
impl Binary for EpollFlags
impl Binary for EfdFlags
impl Binary for AddWatchFlags
impl Binary for InitFlags
impl Binary for MemFdCreateFlag
impl Binary for MRemapFlags
impl Binary for MapFlags
impl Binary for MlockAllFlags
impl Binary for nix::sys::mman::MsFlags
impl Binary for ProtFlags
impl Binary for Persona
impl Binary for Options
impl Binary for QuotaValidFlags
impl Binary for SaFlags
impl Binary for SfdFlags
impl Binary for MsgFlags
impl Binary for SockFlag
impl Binary for Mode
impl Binary for SFlag
impl Binary for FsFlags
impl Binary for ControlFlags
impl Binary for InputFlags
impl Binary for LocalFlags
impl Binary for OutputFlags
impl Binary for TimerFlags
impl Binary for TimerSetTimeFlags
impl Binary for WaitPidFlag
impl Binary for AccessFlags
impl Binary for BigInt
impl Binary for BigUint
impl Binary for m128
impl Binary for m128d
impl Binary for m128i
impl Binary for m256
impl Binary for m256d
impl Binary for m256i
impl Binary for Z0
impl Binary for UInt<UTerm, B0>
impl Binary for UInt<UTerm, B1>
impl Binary for UTerm
impl Binary for f32x4
impl Binary for f32x8
impl Binary for f64x2
impl Binary for f64x4
impl Binary for i8x16
impl Binary for i8x32
impl Binary for i16x8
impl Binary for i16x16
impl Binary for i32x4
impl Binary for i32x8
impl Binary for i64x2
impl Binary for i64x4
impl Binary for u8x16
impl Binary for u8x32
impl Binary for u16x8
impl Binary for u16x16
impl Binary for u32x4
impl Binary for u32x8
impl Binary for u64x2
impl Binary for u64x4
impl Binary for PollEvents
impl Binary for f16
Available on non-
target_arch=spirv only.