pub trait LowerExp {
// Required method
fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>;
}Expand description
e formatting.
The LowerExp trait should format its output in scientific notation with a lower-case e.
For more information on formatters, see the module-level documentation.
Examples
Basic usage with f64:
let x = 42.0; // 42.0 is '4.2e1' in scientific notation
assert_eq!(format!("{x:e}"), "4.2e1");Implementing LowerExp on a type:
use std::fmt;
struct Length(i32);
impl fmt::LowerExp for Length {
fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
let val = f64::from(self.0);
fmt::LowerExp::fmt(&val, f) // delegate to f64's implementation
}
}
let l = Length(100);
assert_eq!(
format!("l in scientific notation is: {l:e}"),
"l in scientific notation is: 1e2"
);
assert_eq!(
format!("l in scientific notation is: {l:05e}"),
"l in scientific notation is: 001e2"
);Required Methods
1.0.0 · Sourcefn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>
fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>
Formats the value using the given formatter.
Errors
This function should return Err if, and only if, the provided Formatter returns Err.
String formatting is considered an infallible operation; this function only
returns a Result because writing to the underlying stream might fail and it must
provide a way to propagate the fact that an error has occurred back up the stack.
Implementors
impl LowerExp for f16
impl LowerExp for f32
impl LowerExp for f64
impl LowerExp for i8
impl LowerExp for i16
impl LowerExp for i32
impl LowerExp for i64
impl LowerExp for i128
impl LowerExp for isize
impl LowerExp for u8
impl LowerExp for u16
impl LowerExp for u32
impl LowerExp for u64
impl LowerExp for u128
impl LowerExp for usize
impl LowerExp for bf16
Available on non-
target_arch=spirv only.impl LowerExp for m128
impl LowerExp for m128d
impl LowerExp for m128i
impl LowerExp for m256
impl LowerExp for m256d
impl LowerExp for m256i
impl LowerExp for f32x4
impl LowerExp for f32x8
impl LowerExp for f64x2
impl LowerExp for f64x4
impl LowerExp for i8x16
impl LowerExp for i8x32
impl LowerExp for i16x8
impl LowerExp for i16x16
impl LowerExp for i32x4
impl LowerExp for i32x8
impl LowerExp for i64x2
impl LowerExp for i64x4
impl LowerExp for u8x16
impl LowerExp for u8x32
impl LowerExp for u16x8
impl LowerExp for u16x16
impl LowerExp for u32x4
impl LowerExp for u32x8
impl LowerExp for u64x2
impl LowerExp for u64x4
impl LowerExp for f16
Available on non-
target_arch=spirv only.